pub struct ParserArtifactIdentity(/* private fields */);Expand description
Authenticated identity of one complete verified platform-pack artifact.
This is the BLAKE3 of the exact immutable artifact-manifest bytes, which in turn bind the worker, logical capability manifest, and grammar payloads. It is not the identity of a grammar currently loaded into the worker.
Implementations
Sourceimpl ParserArtifactIdentity
impl ParserArtifactIdentity
Sourcepub const fn new(digest: ParserContentDigest) -> Self
pub const fn new(digest: ParserContentDigest) -> Self
Construct a pack-artifact identity from its authenticated BLAKE3 digest.
Sourcepub const fn digest(&self) -> &ParserContentDigest
pub const fn digest(&self) -> &ParserContentDigest
Borrow the canonical platform-pack artifact digest.