ParserFrame

Struct ParserFrame 

pub struct ParserFrame<'a> { /* private fields */ }
One exactly framed borrowed parser payload.

Implementations

Source

impl<'a> ParserFrame<'a>

pub fn decode_exact(bytes: &'a [u8]) -> Result<Self, ParserProtocolError>

Decode exactly one complete frame without allocating its payload.

Header validation, including the declared bound, occurs before the declared length is used to address the payload.

Errors

Returns an error for an invalid header, truncation, or trailing bytes.

pub const fn kind(self) -> ParserFrameKind

Return the validated closed frame kind.

pub const fn payload(self) -> &'a [u8]

Borrow the exact payload bytes.