#[repr(u8)]pub enum ParserFrameKind {
Request = 1,
RawSource = 2,
Progress = 3,
Completion = 4,
Failure = 5,
Ready = 6,
SessionOpen = 7,
}Expand description
Closed frame kinds used on the resident worker’s standard streams.
Variants
Request = 1
Strict JSON parse request from supervisor to worker.
RawSource = 2
Exact unencoded source bytes from supervisor to worker.
Progress = 3
Strict JSON progress observation from worker to supervisor.
Completion = 4
Strict JSON successful completion from worker to supervisor.
Failure = 5
Strict JSON closed failure from worker to supervisor.
Ready = 6
Strict JSON containment-ready state from worker to supervisor.
SessionOpen = 7
Strict JSON session opening from supervisor to a contained worker.
Implementations
Sourceimpl ParserFrameKind
impl ParserFrameKind
Sourcepub const fn maximum_payload_bytes(self) -> u32
pub const fn maximum_payload_bytes(self) -> u32
Return the maximum payload bytes for this frame kind.
Sourcepub const fn is_control(self) -> bool
pub const fn is_control(self) -> bool
Return whether this kind carries strict JSON control data.