pub struct ParserFrame<'a> { /* private fields */ }Expand description
One exactly framed borrowed parser payload.
Implementations
Sourceimpl<'a> ParserFrame<'a>
impl<'a> ParserFrame<'a>
Sourcepub fn decode_exact(bytes: &'a [u8]) -> Result<Self, ParserProtocolError>
pub fn decode_exact(bytes: &'a [u8]) -> Result<Self, ParserProtocolError>
Decode exactly one complete frame without allocating its payload.
Header validation, including the declared bound, occurs before the declared length is used to address the payload.
Errors
Returns an error for an invalid header, truncation, or trailing bytes.
Sourcepub const fn kind(self) -> ParserFrameKind
pub const fn kind(self) -> ParserFrameKind
Return the validated closed frame kind.